@@ -204,11 +204,51 @@ def same_sfr_numbering(reach_data1, reach_data2):
 
 
 def reach_elevations_decrease_downstream(reach_data):
-    """Verify that reach elevations decrease monotonically in the downstream direction."""
+    """Verify that reach values decrease monotonically in the downstream direction."""
     rd = reach_data.reset_index()
-    elev = dict(zip(rd.rno, rd.strtop))
-    dnelev = {rid: elev[rd.outreach[i]] if rd.outreach[i] != 0
-    else -9999 for i, rid in enumerate(rd.rno)}
-    diffs = np.array([(dnelev[i] - elev[i]) if dnelev[i] != -9999
-                      else -.001 for i in rd.rno])
+    return check_monotonicity(rd.rno, rd.outreach, rd.strtop)
+    #elev = dict(zip(rd.rno, rd.strtop))
+    #dnelev = {rid: elev[rd.outreach[i]] if rd.outreach[i] != 0
+    #else -9999 for i, rid in enumerate(rd.rno)}
+    #diffs = np.array([(dnelev[i] - elev[i]) if dnelev[i] != -9999
+    #                  else -.001 for i in rd.rno])
+    #return np.max(diffs) <= 0
+
+
+def check_monotonicity(ids, toids, values, decrease=True):
+    """Verify that values decrease or increase monotonically
+    in the downstream direction.
+
+    Parameters
+    ----------
+    ids : sequence
+        Sequence of line identifiers (e.g. COMIDs)
+    toids : sequence
+        Sequence of downstream routing connections (line identifiers)
+    values : numeric
+        Values to check.
+    decrease : bool
+        If True, verify that values strictly decrease in the downstream direction,
+        if False, verify that values strictly increase in the downstream direction.
+
+    Returns
+    -------
+    is_monotonic : bool
+        Whether or not values change monotonically in the downstream direction.
+    """
+    if isinstance(ids, pd.Series):
+        ids = ids.values
+    if isinstance(toids, pd.Series):
+        toids = toids.values
+    # a fill value that is larger than any value in values
+    # (in absolute terms)
+    default = -10 * np.max(np.abs(values))
+    values = np.array(values)
+    if not decrease:
+        values *= -1
+    values_dict = dict(zip(ids, values))
+    downstream_values = {rid: values_dict[toids[i]] if toids[i] != 0
+              else default for i, rid in enumerate(ids)}
+    diffs = np.array([(downstream_values[i] - values_dict[i]) if downstream_values[i] != default
+                      else -.001 for i in ids])
     return np.max(diffs) <= 0
